@@ -4,12 +4,15 @@
 (*                                                                     *)
 (*            Jun Furuse, projet Cristal, INRIA Rocquencourt           *)
 (*                                                                     *)
-(*  Copyright 1999,2000,2001,2002,2001,2002                            *)
+(*  Copyright 1999-2004,                                               *)
 (*  Institut National de Recherche en Informatique et en Automatique.  *)
 (*  Distributed only by permission.                                    *)
 (*                                                                     *)
 (***********************************************************************)
-let table = 
+
+(* $Id: jis_table.ml,v 1.4 2004/09/27 08:10:18 weis Exp $ *)
+
+let table =
 "0\0000\0010\002\255\012\255\0140\251\255\026\255\027\255\031\255\0010\155\
 0\156\000\180\255@\000\168\255>\255\227\255?0\2530\2540\1570\1580\003N\221\
 0\0050\0060\0070\252\032\021\032\016\255\015\255<\255^\"%\255\\\032&\032%\
@@ -625,4 +628,4 @@ y\148\250\027y\155z\209z\231\250\028z\235{\158\250\029}H}\\}\183}\160}\214\
 H\149\146\249\220\250)\150\157\150\175\1513\151;\151C\151M\151O\151Q\151U\
 \152W\152e\250*\250+\153'\250,\153\158\154N\154\217\154\220\155u\155r\155\
 \143\155\177\155\187\156\000\157p\157k\250-\158\025\158\2090\2510\251!p!q\
-!r!s!t!u!v!w!x!y\255\226\255\228\255\007\255\002"
+!r!s!t!u!v!w!x!y\255\226\255\228\255\007\255\002";;
