@@ -2,23 +2,26 @@
 (*                                                                     *)
 (*                           Objective Caml                            *)
 (*                                                                     *)
+(*            Franois Pessaux, projet Cristal, INRIA Rocquencourt     *)
+(*            Pierre Weis, projet Cristal, INRIA Rocquencourt          *)
 (*            Jun Furuse, projet Cristal, INRIA Rocquencourt           *)
 (*                                                                     *)
-(*  Copyright 1999,2000,2001,2002,2001,2002                            *)
+(*  Copyright 1999-2004,                                               *)
 (*  Institut National de Recherche en Informatique et en Automatique.  *)
 (*  Distributed only by permission.                                    *)
 (*                                                                     *)
 (***********************************************************************)
-open OImage
-open Gif
 
-let load_first name opts =
-  OImage.make (Gif.load_first name opts)
-;;
+(* $Id: oGif.ml,v 1.7 2004/09/07 07:31:04 weis Exp $ *)
+
+open OImages;;
+open Gif;;
+
+let load_first name opts = OImages.make (Gif.load_first name opts);;
 
 let save_image name opts image =
   let img = image#image in
   match img with
-    Image.Index8 bmp ->
+  | Images.Index8 bmp ->
       Gif.save_image name opts img
-  | _ -> raise Wrong_image_class
+  | _ -> raise Wrong_image_class;;
