@@ -4,20 +4,18 @@
 (*                                                                     *)
 (*            Jun Furuse, projet Cristal, INRIA Rocquencourt           *)
 (*                                                                     *)
-(*  Copyright 1999,2000,2001,2002,2001,2002                            *)
+(*  Copyright 1999-2004,                                               *)
 (*  Institut National de Recherche en Informatique et en Automatique.  *)
 (*  Distributed only by permission.                                    *)
 (*                                                                     *)
 (***********************************************************************)
-open OImage
 
-let load_as_rgb24 name opts =
-  OImage.make (Png.load_as_rgb24 name opts)
-;;
+(* $Id: oPng.ml,v 1.8 2004/09/07 07:31:06 weis Exp $ *)
 
-let load name opts =
-  OImage.make (Png.load name opts)
-;;
+open OImages;;
 
-let save name opts image = Png.save name opts image#image
-;;
+let load_as_rgb24 name opts = OImages.make (Png.load_as_rgb24 name opts);;
+
+let load name opts = OImages.make (Png.load name opts);;
+
+let save name opts image = Png.save name opts image#image;;
