@@ -4,12 +4,14 @@
 (*                                                                     *)
 (*            Jun Furuse, projet Cristal, INRIA Rocquencourt           *)
 (*                                                                     *)
-(*  Copyright 1999,2000,2001,2002,2001,2002                            *)
+(*  Copyright 1999-2004,                                               *)
 (*  Institut National de Recherche en Informatique et en Automatique.  *)
 (*  Distributed only by permission.                                    *)
 (*                                                                     *)
 (***********************************************************************)
-open OImage
 
-let load name opts =
-  OImage.make (Xpm.load name opts)
+(* $Id: oXpm.ml,v 1.7 2004/09/07 07:31:08 weis Exp $ *)
+
+open OImages;;
+
+let load name opts = OImages.make (Xpm.load name opts);;
